@@ -8,7 +8,7 @@ import warnings
 import pickle
 from hashlib import md5
 
-try:
+try:  # pragma: no cover
     from StringIO import StringIO
 except ImportError:
     from io import StringIO
@@ -710,7 +710,7 @@ class NexusReader(object):
         if filename.endswith('.gz'):
             handle = gzip.open(filename, 'rb') # pragma: no cover
         else:
-            handle = open(filename, 'rU')
+            handle = open(filename, 'r')
         self._read(handle)
         handle.close()
 
@@ -781,7 +781,3 @@ class NexusReader(object):
         handle = open(filename, 'w')
         handle.writelines(self.write())
         handle.close()
-
-
-if __name__ == '__main__':
-    pass
