@@ -1,5 +1,5 @@
 """Contains Nexus Manipulation Tools that operate on Site/Characters"""
-from collections import Iterable
+from collections import Counter, Iterable
 from nexus.writer import NexusWriter
 from nexus.tools.check_for_valid_NexusReader import check_for_valid_NexusReader
 
@@ -23,7 +23,7 @@ def find_constant_sites(nexus_obj):
         for taxa, data in nexus_obj.data:
             c = data[i]
             if c in ('?', '-'):
-                continue
+                continue  # pragma: no cover
             elif c not in states:
                 states.append(c)
 
@@ -53,7 +53,7 @@ def find_unique_sites(nexus_obj):
         missing = 0
         for taxa, characters in nexus_obj.data:
             c = characters[i]
-            if c in (u'?', u'-'):
+            if c in ('?', '-'):
                 missing += 1
             else:
                 members[c] = members.get(c, 0) + 1
@@ -83,8 +83,6 @@ def count_site_values(nexus_obj, characters=('-', '?')):
     :raises AssertionError: if nexus_obj is not a nexus
     :raises NexusFormatException: if nexus_obj does not have a `data` block
     """
-    # just check it's iterable. Don't _change_ it to an iterable or we
-    # won't be able to compare the characters properly below.
     if not isinstance(characters, Iterable):
         raise TypeError("characters should be iterable")
 
@@ -191,3 +189,31 @@ def tally_by_taxon(nexus_obj):
             tally[taxon][char] = tally[taxon].get(char, [])
             tally[taxon][char].append(label)
     return tally
+
+
+def count_binary_set_size(nexus_obj):
+    """
+    Counts the number of sites by their size (i.e. how many sites have two
+    members, etc)
+
+    Returns a dictionary of the set size and count
+
+    :param nexus_obj: A `NexusReader` instance
+    :type nexus_obj: NexusReader
+
+    :return: A Dictionary
+    :raises AssertionError: if nexus_obj is not a nexus
+    :raises NexusFormatException: if nexus_obj does not have a `data` block
+
+    e.g. {
+        0: 0,
+        1: 100,
+        2: 20,
+    }
+    """
+    check_for_valid_NexusReader(nexus_obj, required_blocks=['data'])
+    tally = Counter()
+    for char_id in nexus_obj.data.characters:
+        char = nexus_obj.data.characters[char_id]
+        tally[len([v for v in char.values() if v == '1'])] += 1
+    return tally
